@@ -26,11 +26,11 @@ Lavoco::Web::Editor - FastCGI app to edit flat-files.
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 $VERSION = eval $VERSION;
 
@@ -499,7 +499,35 @@ sub _handler
 
                     if ( exists $req->parameters->{ content } )
                     {
-                        write_file( $stash{ app }->_base . '/' . $folder->{ path } . '/' . $req->parameters->{ file }, { binmode => ':utf8' }, $req->parameters->{ content } );
+                        $log->debug( "We've got some content" );
+
+                        if ( $req->parameters->{ file } =~ /\.json/ )
+                        {
+                            $log->debug( "It's a JSON file" );
+
+                            #########################
+                            # basic json validation #
+                            #########################
+
+                            eval {
+                                my $json = JSON->new;
+
+                                $json->relaxed( 1 );
+
+                                $json->decode( $req->parameters->{ content } );
+                            };
+                            
+                            $log->debug( $@ ) if $@;
+
+                            $stash{ error } = $@ if $@;
+                        }
+
+                        if ( ! exists $stash{ error } )
+                        {
+                            write_file( $stash{ app }->_base . '/' . $folder->{ path } . '/' . $req->parameters->{ file }, { binmode => ':utf8' }, $req->parameters->{ content } );
+                        
+                            $stash{ success } = "Saved OK";
+                        }
 
                         $stash{ file } = $req->parameters->{ file };
 
@@ -525,7 +553,34 @@ sub _handler
                     }
                     else
                     {
-                        write_file( $stash{ app }->_base . '/' . $file, { binmode => ':utf8' }, $req->parameters->{ content } );
+
+                        if ( $req->parameters->{ file } =~ /\.json/ )
+                        {
+                            $log->debug( "It's a JSON file" );
+
+                            #########################
+                            # basic json validation #
+                            #########################
+
+                            eval {
+                                my $json = JSON->new;
+
+                                $json->relaxed( 1 );
+
+                                $json->decode( $req->parameters->{ content } );
+                            };
+                            
+                            $log->debug( $@ ) if $@;
+
+                            $stash{ error } = $@ if $@;
+                        }
+
+                        if ( ! exists $stash{ error } )
+                        {
+                            write_file( $stash{ app }->_base . '/' . $file, { binmode => ':utf8' }, $req->parameters->{ content } );
+
+                            $stash{ success } = "Saved OK";
+                        }
 
                         $stash{ file } = $req->parameters->{ file };
 
@@ -542,6 +597,8 @@ sub _handler
         # responding with a template #
         ##############################
 
+        $stash{ error } =~ s/ at \/.*$// if exists $stash{ error };
+
         $res->status( 200 );
 
         my $tt = Template->new( ENCODING => 'UTF-8' );
@@ -631,6 +688,7 @@ EOF
         <style>
             body { font-family: Tahoma,Arial,Helvetica,sans-serif; }
             ul li { margin-top: 5px; }
+            a,a:visited { color: #0000EE; }
         </style>
     </head>
 
@@ -675,6 +733,7 @@ EOF
     <head>
         <style>
             body { font-family: Tahoma,Arial,Helvetica,sans-serif; }
+            a,a:visited { color: #0000EE; }
         </style>
     </head>
 
@@ -682,7 +741,7 @@ EOF
 
         <h1><a href="/">Website Content Editor</a></h2>
 
-        <h2>[% folder %]/[% file %]</h2>
+        <h2>[% folder %]/[% file %][% IF success %] - <span style="color: #0c0;">[% success %]</span>[% END %][% IF error %] - <span style="color: #f00;">[% error %]</span>[% END %]</h2>
 
         <form action="/" method="POST">
             [% IF folder %]        
